@@ -325,8 +325,9 @@ namespace LMM {
 			    double dosageLine[], bool verboseStats,
 			    const std::vector <StatsDataRetroLOCO> &retroData, double info=-9)
       const;
-    std::string getSnpStatsBgen2(uchar *buf, uint bufLen, const uchar *zBuf, uint zBufLen,
-				 uint Nbgen, const std::vector <uint64> &bgenIndivInds,
+    std::string getSnpStatsBgen2(uint CompressedSNPBlocks, uchar *buf, uint bufLen,
+				 const uchar *zBuf, uint zBufLen, uint Nbgen,
+				 const std::vector <uint64> &bgenIndivInds,
 				 const std::string &snpName, int chrom, int physpos, double genpos,
 				 const std::string &allele1, const std::string &allele0,
 				 double snpCovCompVec[], bool verboseStats,
