@@ -54,8 +54,8 @@ int main(int argc, char *argv[]) {
 
   cout << "                      +-----------------------------+" << endl;
   cout << "                      |                       ___   |" << endl;
-  cout << "                      |   BOLT-LMM, v2.4     /_ /   |" << endl;
-  cout << "                      |   July 22, 2022       /_/   |" << endl;
+  cout << "                      |   BOLT-LMM, v2.4.1   /_ /   |" << endl;
+  cout << "                      |   November 16, 2022   /_/   |" << endl;
   cout << "                      |   Po-Ru Loh            //   |" << endl;
   cout << "                      |                        /    |" << endl;
   cout << "                      +-----------------------------+" << endl;
