@@ -25,6 +25,7 @@
 #include <cassert>
 
 #include "zlib.h"
+#include "zstd.h"
 
 #include <boost/iostreams/filtering_stream.hpp>
 #include <boost/iostreams/filter/gzip.hpp>
@@ -277,7 +278,7 @@ namespace FileUtils {
     fseek_check(fin, L_H-20, SEEK_CUR); //cout << "skipping L_H-20 = " << L_H-20 << " bytes (free data area)" << endl;
     uint flags; fread_check(&flags, 4, 1, fin); //cout << "flags: " << flags << endl;
     uint CompressedSNPBlocks = flags&3; cout << "CompressedSNPBlocks: " << CompressedSNPBlocks << endl;
-    assert(CompressedSNPBlocks==1); // REQUIRE CompressedSNPBlocks==1
+    assert(CompressedSNPBlocks==1 || CompressedSNPBlocks==2); // REQUIRE CompressedSNPBlocks==1||2
     uint Layout = (flags>>2)&0xf; cout << "Layout: " << Layout << endl;
     assert(Layout==1 || Layout==2); // REQUIRE Layout==1 or Layout==2
 
@@ -336,9 +337,18 @@ namespace FileUtils {
 
       uLongf destLen = D, bufLen = D, zBufLen = C-4;
       //cout << "bufLen = " << bufLen << " zBufLen = " << zBufLen << endl;
-      if (uncompress(buf, &destLen, zBuf, zBufLen) != Z_OK || destLen != bufLen) {
-	cerr << "ERROR: uncompress() failed" << endl;
-	exit(1);
+      if (CompressedSNPBlocks == 1) {
+	uLongf destLen = bufLen;
+	if (uncompress(buf, &destLen, zBuf, zBufLen) != Z_OK || destLen != bufLen) {
+	  cerr << "ERROR: uncompress() failed" << endl;
+	  exit(1);
+	}
+      }
+      else {
+	if (ZSTD_decompress(buf, bufLen, zBuf, zBufLen) != bufLen) {
+	  cerr << "ERROR: ZSTD_decompress() failed" << endl;
+	  exit(1);
+	}
       }
       uchar *bufAt = buf;
       uint N = bufAt[0]|(bufAt[1]<<8)|(bufAt[2]<<16)|(bufAt[3]<<24); bufAt += 4;
